pub struct DynamicPoolConfig {
pub enable_dynamic_scaling: bool,
pub scale_up_threshold: f64,
pub scale_down_threshold: f64,
pub scale_down_cooldown_secs: u64,
pub min_connections: u32,
pub max_connections: u32,
pub scale_up_step: u32,
pub scale_down_step: u32,
}Fields
enable_dynamic_scaling: boolscale_up_threshold: f64scale_down_threshold: f64scale_down_cooldown_secs: u64min_connections: u32max_connections: u32scale_up_step: u32scale_down_step: u32Trait Implementations
Sourceimpl Clone for DynamicPoolConfig
impl Clone for DynamicPoolConfig
Sourcefn clone(&self) -> DynamicPoolConfig
fn clone(&self) -> DynamicPoolConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DynamicPoolConfig
impl Debug for DynamicPoolConfig
Sourceimpl Default for DynamicPoolConfig
impl Default for DynamicPoolConfig
Sourceimpl<'py> IntoPyObject<'py> for DynamicPoolConfig
impl<'py> IntoPyObject<'py> for DynamicPoolConfig
Sourcetype Target = DynamicPoolConfig
type Target = DynamicPoolConfig
The Python output type
Sourcetype Output = Bound<'py, <DynamicPoolConfig as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <DynamicPoolConfig as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for DynamicPoolConfig
impl PyClass for DynamicPoolConfig
Sourceimpl PyClassImpl for DynamicPoolConfig
impl PyClassImpl for DynamicPoolConfig
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype ThreadChecker = SendablePyClass<DynamicPoolConfig>
type ThreadChecker = SendablePyClass<DynamicPoolConfig>
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
fn dict_offset() -> Option<isize>
fn weaklist_offset() -> Option<isize>
Sourceimpl PyClassNewTextSignature for DynamicPoolConfig
impl PyClassNewTextSignature for DynamicPoolConfig
const TEXT_SIGNATURE: &'static str = "()"
Sourceimpl PyMethods<DynamicPoolConfig> for PyClassImplCollector<DynamicPoolConfig>
impl PyMethods<DynamicPoolConfig> for PyClassImplCollector<DynamicPoolConfig>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for DynamicPoolConfig
impl PyTypeInfo for DynamicPoolConfig
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type or a subclass of this type.fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
fn is_exact_type_of(object: &Bound<'_, PyAny>) -> bool
Checks if
object is an instance of this type.impl DerefToPyAny for DynamicPoolConfig
impl ExtractPyClassWithClone for DynamicPoolConfig